"""
DRF Scoped Permissions
~~~~~~~~~~~~~~~~~~~~~

Resource-scoped API key and group permissions for Django REST Framework.

:copyright: (c) 2025 Frankapps
:license: MIT, see LICENSE for more details.
"""

__version__ = "0.1.1"
__author__ = "Frankapps"
__email__ = "hello@frankapps.com"
